@@ -11,6 +11,8 @@ compas_assembly
 
     compas_assembly.blender
     compas_assembly.datastructures
+    compas_assembly.geometry
+    compas_assembly.ghpython
     compas_assembly.plotter
     compas_assembly.rhino
 
@@ -26,7 +28,7 @@ __copyright__ = 'Block Research Group - ETH Zurich'
 __license__ = 'MIT License'
 __email__ = 'van.mele@arch.ethz.ch'
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 
 HERE = os.path.dirname(__file__)
