@@ -7,9 +7,6 @@ from compas.geometry import convex_hull
 from compas.topology import unify_cycles
 
 
-__all__ = ['assembly_hull']
-
-
 def assembly_hull(assembly, keys=None, unify=True):
     """Construct the convex hull of an assembly.
 
@@ -53,24 +50,3 @@ def assembly_hull(assembly, keys=None, unify=True):
         faces = unify_cycles(vertices, faces)
 
     return vertices, faces
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-
-    import compas_assembly
-    from compas.datastructures import Mesh
-    from compas_viewers.meshviewer import MeshViewer
-    from compas_assembly.datastructures import Assembly
-
-    assembly = Assembly.from_json(compas_assembly.get('assembly.json'))
-
-    vertices, faces = assembly_hull(assembly)
-    hull = Mesh.from_vertices_and_faces(vertices, faces)
-
-    viewer = MeshViewer()
-    viewer.mesh = hull
-    viewer.show()
