@@ -24,14 +24,6 @@ class Geometry(object):
         -------
         tuple
             0. List of meshes representing the block geometries.
-            1.
+            1. List of block index pairs representing connections or interfaces.
         """
         raise NotImplementedError
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-    pass
