@@ -34,11 +34,3 @@ class Dome(Geometry):
 
         """
         pass
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-    pass
