@@ -26,11 +26,3 @@ class BlockArtist(MeshArtist):
     @block.setter
     def block(self, block):
         self.mesh = block
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == "__main__":
-    pass
